//
// Reticle.h
//

#ifndef RETICLE_H
#define RETICLE_H

// Engine includes.
#include "EventKeyboard.h"
#include "EventMouse.h"
#include "Object.h"
#include "Particle.h"
#include "Precipitation.h"

#define RETICLE_CHAR '+'

class Reticle : public df::Object {

 private:
  df::ParticleType effect;	        // Sparks, smoke, rings, fireworks.
  df::PrecipitationType precipitation;  // Snow, rain, stars.
  df::Color color;                      // Color (if not default).
  float effect_scale;			// Scale for effects.
  float precipitation_scale;		// Scale for precipitation.
  df::Direction direction;		// Up, down, left, right.

 private:
  // Used for custom effects (df-config.txt).
  void addCustomEffect() const; 

  // Update precipitation if type/scale/direction changed.
  void updatePrecipitation();

 public:
  Reticle();

  // Draw reticle on screen.
  int draw(void);

  // Handle events.
  int eventHandler(const df::Event *p_e);
  int mouse(const df::EventMouse *p_mouse_event);
  int key(const df::EventKeyboard *p_key_event);

  // Get particle effect values.
  df::ParticleType getEffect() const;
  df::PrecipitationType getPrecipitation() const;
  df::Color getColor() const;
  df::Direction getDirection() const;
  float getPrecipitationScale() const;
  float getEffectScale() const;

  // Set particle effect values.
  void setEffect(df::ParticleType new_effect);
  void setPrecipitation(df::PrecipitationType new_precipitation);
  void setColor(df::Color new_color);
  void setDirection(df::Direction new_direction);
  void setEffectScale(float new_effect_scale);
  void setPrecipitationScale(float new_effect_scale);
};

#endif // RETICLE_H

