//
// game.cpp
// 

// Engine includes.
#include "Button.h"
#include "Fraps.h"
#include "GameManager.h"
#include "LogManager.h"

// Game includes.
#include "ColorButton.h"
#include "DirectionButton.h"
#include "EffectButton.h"
#include "EffectScaleButton.h"
#include "demo.h"
#include "PrecipitationButton.h"
#include "PrecipitationScaleButton.h"
#include "Reticle.h"

// Function prototypes.
void populateWorld();
void clickEffect();
void clickColor();
void clickScale();
 
int main(int argc, char *argv[]) {

  // Start up game manager.
  if (GM.startUp())  {
    LM.writeLog("Error starting game manager!");
    GM.shutDown();
    return 0;
  }

  // Log version info.
  LM.writeLog("Particle-demo (v%.1f) - a demonstration of Dragonfly particles.\n", VERSION);

  // Populate game world with some objects.
  populateWorld();

  // Uncomment below for Fraps.
  /*
  df::Fraps *p_f = new df::Fraps();
  p_f -> setPosition(df::Vector(WM.getView().getHorizontal()*11/16, 1));
  p_f -> setBorder(false);
  */

  // Run demo (this blocks until game loop is over).
  GM.run();
 
  // Shut everything down.
  GM.shutDown();
}
 
// Populate world with some objects.
void populateWorld() {

  // Reticle.
  Reticle *p_reticle = new Reticle();

  // Effect: Smoke, Sparks, Rings, Fireworks, Custom (from df-config.txt).
  new EffectButton(p_reticle);

  // Color.
  new ColorButton(p_reticle);

  // Effect scale.
  new EffectScaleButton(p_reticle);

  // Precipitation: SNOW, RAIN, STARFIELD, OFF.
  new PrecipitationButton(p_reticle);

  // Precipitation scale.
  new PrecipitationScaleButton(p_reticle);

  // Precipitation direction.
  new DirectionButton(p_reticle);
}
